# Usesless

![Logo](https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQs3E8chgkVmnN27XTcaAXgP84AFHi0x3X49Q&usqp=CAU)

This is a Chinese site that uses the OpenAI templates (GPT-3.5 and GPT-4). It is very fast and you can get answers in real time, which facilitates the process.

[How to Use](https://github.com/uesleibros/OpenGPT/tree/main/opengpt/usesless/DOC.md)

## Customization

Unlike other models already worked on, this one supports you to adjust the temperature at which the response will be generated. Useful for generating more creative or more objective texts.
If you are interested in going deeper into this part of the model temperature, you can search this site: https://ai.stackexchange.com/questions/32477/what-is-the-temperature-in-the-gpt-models
